@@ -1,7 +1,12 @@
+"""The main command processing module.
+
+This module requires refactoring, improvements to its argument handling,
+and needs to be converted to a Class.
+"""
+
 import logging
 import pprint
 import time
-from collections import namedtuple
 from datetime import timedelta
 from distutils.version import StrictVersion
 from os import get_terminal_size
@@ -860,10 +865,13 @@ def remove_from_queue(speaker, action, args, soco_function, use_local_speaker_li
     # Walk though the list of tracks from position 1, removing items marked '0'
     # Account for the queue shift by keeping count of those deleted
     logging.info("Created map of queue items to delete (==0) {}".format(queue))
+    # Note: do not switch the loop below to 'enumerate'. Yield behaviour breaks
+    # the sequencing of requests to Sonos.
+    # pylint: disable = consider-using-enumerate
     count_removed = 0
-    for idx, item in enumerate(queue):
-        if item == 0:
-            updated_index = idx - count_removed
+    for index in range(len(queue)):
+        if queue[index] == 0:
+            updated_index = index - count_removed
             speaker.remove_from_queue(updated_index)
             logging.info(
                 "Removing queue item at (adjusted) index {}".format(updated_index + 1)
@@ -1838,7 +1846,9 @@ def album_art(speaker, action, args, soco_function, use_local_speaker_list):
         metadata = info["metadata"]
         data = parse(metadata)
         album_art_uri = data["DIDL-Lite"]["item"]["upnp:albumArtURI"]
+        logging.info("Album art URI = ".format(album_art_uri))
     except:
+        logging.info("No album art URI available")
         print("Album art not available")
         return True
 
@@ -1969,6 +1979,83 @@ def trueplay(speaker, action, args, soco_function, use_local_speaker_list):
     return True
 
 
+@zero_parameters
+def groupstatus(speaker, action, args, soco_function, use_local_speaker_list):
+    """Determine the grouped/paired/bonded status of a speaker."""
+
+    visible_speakers = False
+    invisible_speakers = False
+    coordinator = None
+
+    for grouped_speaker in speaker.group.members:
+        if speaker is grouped_speaker:
+            continue
+        if grouped_speaker.is_visible:
+            visible_speakers = True
+        if not grouped_speaker.is_visible:
+            invisible_speakers = True
+        if grouped_speaker.is_coordinator:
+            coordinator = grouped_speaker
+
+    logging.info(
+        "Visible = {}, Coordinator = {}, Speakers in Group = {}, Other Visible Speakers = {}, Other Invisible Speakers = {}".format(
+            speaker.is_visible,
+            speaker.is_coordinator,
+            len(speaker.group.members),
+            visible_speakers,
+            invisible_speakers,
+        )
+    )
+
+    if len(speaker.group.members) == 1:
+        print("Standalone")
+
+    if speaker.is_visible and speaker.is_coordinator and invisible_speakers:
+        print("Paired or bonded, coordinator")
+
+    if not speaker.is_visible:
+        print(
+            "Paired or bonded, not coordinator [coordinator = {} @ {}]".format(
+                coordinator.player_name, coordinator.ip_address
+            )
+        )
+
+    if speaker.is_visible and speaker.is_coordinator and visible_speakers:
+        print("Grouped, coordinator")
+
+    if speaker.is_visible and not speaker.is_coordinator:
+        print(
+            "Grouped, not coordinator [coordinator = {} @ {}]".format(
+                coordinator.player_name, coordinator.ip_address
+            )
+        )
+
+    return True
+
+
+@zero_parameters
+def pauseplay(speaker, action, args, soco_function, use_local_speaker_list):
+    """Invert a STOPPED or PAUSED STATE."""
+
+    state = speaker.get_current_transport_info()["current_transport_state"]
+    logging.info("Speaker '{}' is in a '{}' state".format(speaker.player_name, state))
+
+    if state in ["PLAYING"]:
+        try:
+            logging.info("Trying 'pause'")
+            speaker.pause()
+        except:
+            logging.info("'Pause' failed ... using 'stop'")
+            speaker.stop()
+
+    elif state in ["STOPPED", "PAUSED_PLAYBACK"]:
+        logging.info("Trying 'play'")
+        speaker.play()
+
+    return True
+
+
+
 def process_action(speaker, action, args, use_local_speaker_list=False):
     sonos_function = actions.get(action, None)
     if sonos_function:
@@ -2296,4 +2383,6 @@ actions = {
     "play_fav_radio_station_no": SonosFunction(play_favourite_radio_number, "", True),
     "pfrsn": SonosFunction(play_favourite_radio_number, "", True),
     "album_art": SonosFunction(album_art, "", True),
+    "groupstatus": SonosFunction(groupstatus),
+    "pauseplay": SonosFunction(pauseplay, "", True),
 }
