@@ -1,4 +1,4 @@
-""" SoCo-CLI interactive mode handler """
+"""SoCo-CLI interactive mode handler."""
 
 import logging
 
@@ -26,6 +26,7 @@ from soco_cli.utils import (
     save_readline_history,
     set_interactive,
     speaker_cache,
+    version,
 )
 
 from .wait_actions import process_wait
@@ -37,6 +38,16 @@ am = AliasManager()
 def interactive_loop(
     speaker_name, use_local_speaker_list=False, no_env=False, single_keystroke=False
 ):
+    """
+    The main interactive loop for gathering and processing interactive commands.
+
+    Args:
+        speaker_name (str): The name of the speaker supplied if supplied on the command
+            line.
+        use_local_speaker_list (bool): Whether to use cached discovery.
+        no_env (bool): Whether to ignore environment variables.
+        single_keystroke (bool): Whether to start in single keystroke mode.
+    """
 
     speaker = None
     saved_speaker = None
@@ -72,7 +83,7 @@ def interactive_loop(
         readline.set_completer_delims(" ")
         _get_readline_history()
 
-    single_keystroke = single_keystroke
+    single_keystroke = single_keystroke if RL else False
 
     # Input loop
     while True:
@@ -82,12 +93,11 @@ def interactive_loop(
             prompt = "SoCo-CLI [] > "
 
         if single_keystroke:
+            prompt = prompt.replace("SoCo-CLI", "SoCo-CLI SK")
+            prompt = prompt.replace(">", ">>")
+            print(prompt, flush=True, end="")
             command_line = get_keystroke()
-            if speaker_name and speaker:
-                speaker_text = "[{}]".format(speaker.player_name)
-            else:
-                speaker_text = "[]"
-            print("{} Command =".format(speaker_text), command_line)
+            print(command_line)
             if command_line == "x":
                 single_keystroke = False
                 continue
@@ -161,6 +171,12 @@ def interactive_loop(
                 process_wait(command)
                 continue
 
+            if command_lower in ["version"]:
+                print()
+                version()
+                print()
+                continue
+
             # Is the input a number in the range of speaker numbers?
             try:
                 speaker_number = int(command_lower)
@@ -357,6 +373,7 @@ COMMANDS = [
     "single-keystroke",
     "sk",
     "speakers",
+    "version",
 ]
 
 
@@ -430,7 +447,8 @@ This is SoCo-CLI interactive mode. Interactive commands are as follows:
                     or just enter '0'.
     'sk'        :   Enters 'single keystroke' mode. (Also 'single-keystroke'.)
                     (Not supported on Windows).
-    'speakers'  :   List the names of all available speakers
+    'speakers'  :   List the names of all available speakers.
+    'version'   :   Print the versions of SoCo-CLI, SoCo, and Python in use.
     
     The command syntax is the same as when using 'sonos' from the command line.
     If a speaker been set, the speaker name is omitted from the command.
