@@ -1,4 +1,7 @@
-"""Captures single keystrokes"""
+"""Captures single keystrokes.
+
+This feature is currently not available on Windows.
+"""
 
 import sys
 
@@ -11,6 +14,8 @@ except ImportError:
 
 
 def get_keystroke():
+    """Waits for a keypress, then returns it."""
+
     result = None
     fd = sys.stdin.fileno()
     oldterm = termios.tcgetattr(fd)
