@@ -1,4 +1,5 @@
-#!/usr/bin/env python3
+"""The main entry point into the 'sonos' command."""
+
 import argparse
 import logging
 import pprint
